about summary refs log tree commit diff
path: root/sysdeps
diff options
context:
space:
mode:
authorSiddhesh Poyarekar <siddhesh@redhat.com>2014-09-12 12:31:05 +0530
committerSiddhesh Poyarekar <siddhesh@redhat.com>2014-09-12 12:31:05 +0530
commit5379aebddd0a35c052e7149fb4ff88b49676516e (patch)
tree96b4a224f7b88f8ffc7c68705a2bfd32e7ed8d17 /sysdeps
parent8c0ab919f63dc03a420751172602a52d2bea59a8 (diff)
downloadglibc-5379aebddd0a35c052e7149fb4ff88b49676516e.tar.gz
glibc-5379aebddd0a35c052e7149fb4ff88b49676516e.tar.xz
glibc-5379aebddd0a35c052e7149fb4ff88b49676516e.zip
Enhance tst-xmmymm.sh to detect zmm register usage in ld.so (BZ #16194)
2d63a517e4084ec80403cd9f278690fa8b676cc4 added support to save and
restore zmm register in the dynamic linker, but did not enhance
test-xmmymm.sh to detect accidental usage of these registers.  The
patch below adds that check.

The script has also been renamed to tst-ld-sse-use.sh.  To see the
minimal changes, run `git show -M`.

	[BZ #16194]
	* sysdeps/x86/tst-xmmymm.sh: Rename file to...
	* sysdeps/x86/tst-ld-sse-use.sh: ... this.  Check for zmm
	register usage.
	* sysdeps/x86/Makefile: Adjust.
Diffstat (limited to 'sysdeps')
-rw-r--r--sysdeps/x86/Makefile4
-rwxr-xr-xsysdeps/x86/tst-ld-sse-use.sh (renamed from sysdeps/x86/tst-xmmymm.sh)8
2 files changed, 6 insertions, 6 deletions
diff --git a/sysdeps/x86/Makefile b/sysdeps/x86/Makefile
index a96c8bd0b2..087bbdeca0 100644
--- a/sysdeps/x86/Makefile
+++ b/sysdeps/x86/Makefile
@@ -2,8 +2,8 @@ ifeq ($(subdir),elf)
 CFLAGS-.os += $(if $(filter $(@F),$(patsubst %,%.os,$(all-rtld-routines))),\
 		   -mno-sse -mno-mmx)
 
-tests-special += $(objpfx)tst-xmmymm.out
-$(objpfx)tst-xmmymm.out: ../sysdeps/x86/tst-xmmymm.sh $(objpfx)ld.so
+tests-special += $(objpfx)tst-ld-sse-use.out
+$(objpfx)tst-ld-sse-use.out: ../sysdeps/x86/tst-ld-sse-use.sh $(objpfx)ld.so
 	@echo "Checking ld.so for SSE register use.  This will take a few seconds..."
 	$(SHELL) $< $(objpfx) '$(NM)' '$(OBJDUMP)' '$(READELF)' > $@; \
 	$(evaluate-test)
diff --git a/sysdeps/x86/tst-xmmymm.sh b/sysdeps/x86/tst-ld-sse-use.sh
index 69ddb587d4..c707ca9cc9 100755
--- a/sysdeps/x86/tst-xmmymm.sh
+++ b/sysdeps/x86/tst-ld-sse-use.sh
@@ -1,5 +1,5 @@
 #! /bin/bash
 # Make sure no code in ld.so uses xmm/ymm registers on x86-64.
 # Copyright (C) 2009-2014 Free Software Foundation, Inc.
 # This file is part of the GNU C Library.
 
@@ -24,7 +24,7 @@ NM="$2"
 OBJDUMP="$3"
 READELF="$4"
 
-tmp=$(mktemp ${objpfx}tst-xmmymm.XXXXXX)
+tmp=$(mktemp ${objpfx}tst-ld-sse-use.XXXXXX)
 trap 'rm -f "$tmp"' 1 2 3 15
 
 # List of object files we have to test
@@ -80,12 +80,12 @@ echo "object files needed: $tocheck"
 cp /dev/null "$tmp"
 for f in $tocheck; do
   $OBJDUMP -d "$objpfx"../*/"$f" |
-  awk 'BEGIN { last="" } /^[[:xdigit:]]* <[_[:alnum:]]*>:$/ { fct=substr($2, 2, length($2)-3) } /,%[xy]mm[[:digit:]]*$/ { if (last != fct) { print fct; last=fct} }' |
+  awk 'BEGIN { last="" } /^[[:xdigit:]]* <[_[:alnum:]]*>:$/ { fct=substr($2, 2, length($2)-3) } /,%[xyz]mm[[:digit:]]*$/ { if (last != fct) { print fct; last=fct} }' |
   while read fct; do
     if test "$fct" = "_dl_runtime_profile" -o "$fct" = "_dl_x86_64_restore_sse"; then
       continue;
     fi
-    echo "function $fct in $f modifies xmm/ymm" >> "$tmp"
+    echo "function $fct in $f modifies xmm/ymm/zmm" >> "$tmp"
     result=1
   done
 done
@@ -1,5 +1,5 @@
 #! /bin/bash
-# Make sure no code in ld.so uses xmm/ymm registers on x86-64.
+# Make sure no code in ld.so uses xmm/ymm/zmm registers on x86-64.
 # Copyright (C) 2009-2014 Free Software Foundation, Inc.
 # This file is part of the GNU C Library.